@@ -7,30 +7,20 @@ import unittest
 import common
 
 program = None
-if len(sys.argv) == 3:
-    buildDir = sys.argv[1]
-    srcDir = sys.argv[2]
-else:
-    if len(sys.argv) == 2:
-        program = sys.argv[1]
-        if program.endswith('.py'):
-            program = program[:-3]
-    buildDir = '..'
-    srcDir = '.'
+if len(sys.argv) < 2:
+    raise ValueError('Need at least 2 parameters: runtests.py <build-dir> '
+                     '<test-module-1> <test-module-2> ...')
 
-common.importModules(buildDir=buildDir,
-                     srcDir=srcDir)
+buildDir = sys.argv[1]
+files = sys.argv[2:]
 
-SKIP_FILES = ['common', 'runtests',
-              'test_enum', 'test_conversion']
+common.importModules(buildDir=buildDir)
 
 dir = os.path.split(os.path.abspath(__file__))[0]
 os.chdir(dir)
 
 def gettestnames():
-    files = glob.glob('*.py')
     names = map(lambda x: x[:-3], files)
-    map(names.remove, SKIP_FILES)
     return names
 
 suite = unittest.TestSuite()
